@@ -1,5 +1,3 @@
-package org.apache.maven.shared.artifact.filter;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.shared.artifact.filter;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,6 +16,7 @@ package org.apache.maven.shared.artifact.filter;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.shared.artifact.filter;
 
 import java.util.List;
 
@@ -29,17 +28,14 @@ import java.util.List;
  * @see AbstractStrictPatternArtifactFilter
  * @see PatternExcludesArtifactFilter
  */
-public class StrictPatternExcludesArtifactFilter
-    extends AbstractStrictPatternArtifactFilter
-{
+public class StrictPatternExcludesArtifactFilter extends AbstractStrictPatternArtifactFilter {
     /**
      * Creates a new filter that excludes artifacts that match the specified patterns.
      *
      * @param patterns
      *            the list of artifact patterns to match, as described above
      */
-    public StrictPatternExcludesArtifactFilter( List<String> patterns )
-    {
-        super( patterns, false );
+    public StrictPatternExcludesArtifactFilter(List<String> patterns) {
+        super(patterns, false);
     }
 }
