@@ -1,6 +1,4 @@
-package org.apache.maven.shared.artifact.filter.collection;
-
-/* 
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -9,34 +7,32 @@ package org.apache.maven.shared.artifact.filter.collection;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
- * under the License.    
+ * under the License.
  */
+package org.apache.maven.shared.artifact.filter.collection;
 
 /**
  * <p>ArtifactFilterException class.</p>
  *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
  */
-public class ArtifactFilterException
-    extends Exception
-{
+public class ArtifactFilterException extends Exception {
     /**
-     * 
+     *
      */
     private static final long serialVersionUID = 1L;
 
     /**
      * Create an instance.
      */
-    public ArtifactFilterException()
-    {
+    public ArtifactFilterException() {
         super();
     }
 
@@ -46,9 +42,8 @@ public class ArtifactFilterException
      * @param theMessage The message which describes what happends.
      * @param theCause The cause.
      */
-    public ArtifactFilterException( String theMessage, Throwable theCause )
-    {
-        super( theMessage, theCause );
+    public ArtifactFilterException(String theMessage, Throwable theCause) {
+        super(theMessage, theCause);
     }
 
     /**
@@ -56,9 +51,8 @@ public class ArtifactFilterException
      *
      * @param theMessage The message which describes what happends.
      */
-    public ArtifactFilterException( String theMessage )
-    {
-        super( theMessage );
+    public ArtifactFilterException(String theMessage) {
+        super(theMessage);
     }
 
     /**
@@ -66,9 +60,7 @@ public class ArtifactFilterException
      *
      * @param theCause {@link java.lang.Throwable} cause of the problem.
      */
-    public ArtifactFilterException( Throwable theCause )
-    {
-        super( theCause );
+    public ArtifactFilterException(Throwable theCause) {
+        super(theCause);
     }
-
 }
