@@ -1,5 +1,3 @@
-package org.apache.maven.shared.artifact.filter.collection;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,15 +7,19 @@ package org.apache.maven.shared.artifact.filter.collection;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
- * under the License.    
+ * under the License.
  */
+package org.apache.maven.shared.artifact.filter.collection;
+
+import java.util.LinkedHashSet;
+import java.util.Set;
 
 import org.apache.maven.RepositoryUtils;
 import org.apache.maven.artifact.Artifact;
@@ -29,17 +31,12 @@ import org.apache.maven.project.ProjectBuildingRequest;
 import org.apache.maven.project.ProjectBuildingResult;
 import org.eclipse.aether.graph.Dependency;
 
-import java.util.LinkedHashSet;
-import java.util.Set;
-
 /**
  * This filter will exclude everything that is not a dependency of the selected artifact.
  *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
  */
-public class ArtifactTransitivityFilter
-    extends AbstractArtifactsFilter
-{
+public class ArtifactTransitivityFilter extends AbstractArtifactsFilter {
     /**
      * List of dependencyConflictIds of transitiveArtifacts
      */
@@ -65,36 +62,30 @@ public class ArtifactTransitivityFilter
      * @param projectBuilder  the projectBuilder
      * @throws ProjectBuildingException if the project descriptor could not be successfully built
      */
-    public ArtifactTransitivityFilter( Artifact artifact, ProjectBuildingRequest buildingRequest,
-                                       ProjectBuilder projectBuilder )
-        throws ProjectBuildingException
-    {
-        ProjectBuildingRequest request = new DefaultProjectBuildingRequest( buildingRequest );
+    public ArtifactTransitivityFilter(
+            Artifact artifact, ProjectBuildingRequest buildingRequest, ProjectBuilder projectBuilder)
+            throws ProjectBuildingException {
+        ProjectBuildingRequest request = new DefaultProjectBuildingRequest(buildingRequest);
 
-        request.setResolveDependencies( true );
+        request.setResolveDependencies(true);
 
-        ProjectBuildingResult buildingResult = projectBuilder.build( artifact, request );
+        ProjectBuildingResult buildingResult = projectBuilder.build(artifact, request);
 
         DependencyResolutionResult resolutionResult = buildingResult.getDependencyResolutionResult();
-        if ( resolutionResult != null )
-        {
-            for ( Dependency dependency : resolutionResult.getDependencies() )
-            {
-                Artifact mavenArtifact = RepositoryUtils.toArtifact( dependency.getArtifact() );
-                transitiveArtifacts.add( mavenArtifact.getDependencyConflictId() );
+        if (resolutionResult != null) {
+            for (Dependency dependency : resolutionResult.getDependencies()) {
+                Artifact mavenArtifact = RepositoryUtils.toArtifact(dependency.getArtifact());
+                transitiveArtifacts.add(mavenArtifact.getDependencyConflictId());
             }
         }
     }
 
     /** {@inheritDoc} */
-    public Set<Artifact> filter( Set<Artifact> artifacts )
-    {
+    public Set<Artifact> filter(Set<Artifact> artifacts) {
         Set<Artifact> result = new LinkedHashSet<>();
-        for ( Artifact artifact : artifacts )
-        {
-            if ( artifactIsATransitiveDependency( artifact ) )
-            {
-                result.add( artifact );
+        for (Artifact artifact : artifacts) {
+            if (artifactIsATransitiveDependency(artifact)) {
+                result.add(artifact);
             }
         }
         return result;
@@ -106,8 +97,7 @@ public class ArtifactTransitivityFilter
      * @param artifact representing the item to compare.
      * @return true if artifact is a transitive dependency
      */
-    public boolean artifactIsATransitiveDependency( Artifact artifact )
-    {
-        return transitiveArtifacts.contains( artifact.getDependencyConflictId() );
+    public boolean artifactIsATransitiveDependency(Artifact artifact) {
+        return transitiveArtifacts.contains(artifact.getDependencyConflictId());
     }
 }
