@@ -1,5 +1,3 @@
-package org.apache.maven.shared.artifact.filter.collection;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,15 +7,16 @@ package org.apache.maven.shared.artifact.filter.collection;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
- * under the License.    
+ * under the License.
  */
+package org.apache.maven.shared.artifact.filter.collection;
 
 import java.util.LinkedHashSet;
 import java.util.Set;
@@ -29,9 +28,7 @@ import org.apache.maven.artifact.Artifact;
  *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
  */
-public class ProjectTransitivityFilter
-    extends AbstractArtifactsFilter
-{
+public class ProjectTransitivityFilter extends AbstractArtifactsFilter {
 
     private boolean excludeTransitive;
 
@@ -43,28 +40,23 @@ public class ProjectTransitivityFilter
      * @param directDependencies set of direct dependencies.
      * @param excludeTransitive {@code true} exclude transitive deps {@code false} otherwise.
      */
-    public ProjectTransitivityFilter( Set<Artifact> directDependencies, boolean excludeTransitive )
-    {
+    public ProjectTransitivityFilter(Set<Artifact> directDependencies, boolean excludeTransitive) {
         this.excludeTransitive = excludeTransitive;
         this.directDependencies = directDependencies;
     }
 
     /** {@inheritDoc} */
-    public Set<Artifact> filter( Set<Artifact> artifacts )
-    {
+    public Set<Artifact> filter(Set<Artifact> artifacts) {
         // why not just take the directDependencies here?
         // because if this filter is run after some other process, the
         // set of artifacts may not be the same as the directDependencies.
         Set<Artifact> result = artifacts;
 
-        if ( excludeTransitive )
-        {
+        if (excludeTransitive) {
             result = new LinkedHashSet<>();
-            for ( Artifact artifact : artifacts )
-            {
-                if ( artifactIsADirectDependency( artifact ) )
-                {
-                    result.add( artifact );
+            for (Artifact artifact : artifacts) {
+                if (artifactIsADirectDependency(artifact)) {
+                    result.add(artifact);
                 }
             }
         }
@@ -77,12 +69,9 @@ public class ProjectTransitivityFilter
      * @param artifact representing the item to compare.
      * @return true if artifact is a direct dependency
      */
-    public boolean artifactIsADirectDependency( Artifact artifact )
-    {
-        for ( Artifact dependency : this.directDependencies )
-        {
-            if ( dependency.equals( artifact ) )
-            {
+    public boolean artifactIsADirectDependency(Artifact artifact) {
+        for (Artifact dependency : this.directDependencies) {
+            if (dependency.equals(artifact)) {
                 return true;
             }
         }
@@ -94,8 +83,7 @@ public class ProjectTransitivityFilter
      *
      * @return Returns the excludeTransitive.
      */
-    public boolean isExcludeTransitive()
-    {
+    public boolean isExcludeTransitive() {
         return this.excludeTransitive;
     }
 
@@ -104,8 +92,7 @@ public class ProjectTransitivityFilter
      *
      * @param excludeTransitive The excludeTransitive to set.
      */
-    public void setExcludeTransitive( boolean excludeTransitive )
-    {
+    public void setExcludeTransitive(boolean excludeTransitive) {
         this.excludeTransitive = excludeTransitive;
     }
 }
