@@ -1,5 +1,3 @@
-package org.apache.maven.shared.artifact.filter.collection;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,15 +7,16 @@ package org.apache.maven.shared.artifact.filter.collection;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
- * under the License.    
+ * under the License.
  */
+package org.apache.maven.shared.artifact.filter.collection;
 
 import java.util.LinkedHashSet;
 import java.util.Set;
@@ -33,9 +32,7 @@ import static org.apache.maven.shared.artifact.filter.internal.Utils.isNotEmpty;
  *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
  */
-public class ScopeFilter
-    extends AbstractArtifactsFilter
-{
+public class ScopeFilter extends AbstractArtifactsFilter {
 
     private String includeScope;
 
@@ -47,8 +44,7 @@ public class ScopeFilter
      * @param includeScope the scope to be included.
      * @param excludeScope the scope to be excluded.
      */
-    public ScopeFilter( String includeScope, String excludeScope )
-    {
+    public ScopeFilter(String includeScope, String excludeScope) {
         this.includeScope = includeScope;
         this.excludeScope = excludeScope;
     }
@@ -59,97 +55,76 @@ public class ScopeFilter
      * This function determines if filtering needs to be performed. Excludes are
      * ignored if Includes are used.
      */
-    public Set<Artifact> filter( Set<Artifact> artifacts )
-        throws ArtifactFilterException
-    {
+    public Set<Artifact> filter(Set<Artifact> artifacts) throws ArtifactFilterException {
         Set<Artifact> results = artifacts;
 
-        if ( isNotEmpty( includeScope ) )
-        {
-            if ( !Artifact.SCOPE_COMPILE.equals( includeScope ) && !Artifact.SCOPE_TEST.equals( includeScope )
-                && !Artifact.SCOPE_PROVIDED.equals( includeScope ) && !Artifact.SCOPE_RUNTIME.equals( includeScope )
-                && !Artifact.SCOPE_SYSTEM.equals( includeScope ) )
-            {
-                throw new ArtifactFilterException( "Invalid Scope in includeScope: " + includeScope );
+        if (isNotEmpty(includeScope)) {
+            if (!Artifact.SCOPE_COMPILE.equals(includeScope)
+                    && !Artifact.SCOPE_TEST.equals(includeScope)
+                    && !Artifact.SCOPE_PROVIDED.equals(includeScope)
+                    && !Artifact.SCOPE_RUNTIME.equals(includeScope)
+                    && !Artifact.SCOPE_SYSTEM.equals(includeScope)) {
+                throw new ArtifactFilterException("Invalid Scope in includeScope: " + includeScope);
             }
 
             results = new LinkedHashSet<>();
 
-            if ( Artifact.SCOPE_PROVIDED.equals( includeScope ) || Artifact.SCOPE_SYSTEM.equals( includeScope ) )
-            {
-                results = includeSingleScope( artifacts, includeScope );
-            }
-            else
-            {
-                ArtifactFilter saf = new ScopeArtifactFilter( includeScope );
+            if (Artifact.SCOPE_PROVIDED.equals(includeScope) || Artifact.SCOPE_SYSTEM.equals(includeScope)) {
+                results = includeSingleScope(artifacts, includeScope);
+            } else {
+                ArtifactFilter saf = new ScopeArtifactFilter(includeScope);
 
-                for ( Artifact artifact : artifacts )
-                {
-                    if ( saf.include( artifact ) )
-                    {
-                        results.add( artifact );
+                for (Artifact artifact : artifacts) {
+                    if (saf.include(artifact)) {
+                        results.add(artifact);
                     }
                 }
             }
-        }
-        else if ( isNotEmpty( excludeScope ) )
-        {
-            if ( !Artifact.SCOPE_COMPILE.equals( excludeScope ) && !Artifact.SCOPE_TEST.equals( excludeScope )
-                && !Artifact.SCOPE_PROVIDED.equals( excludeScope ) && !Artifact.SCOPE_RUNTIME.equals( excludeScope )
-                && !Artifact.SCOPE_SYSTEM.equals( excludeScope ) )
-            {
-                throw new ArtifactFilterException( "Invalid Scope in excludeScope: " + excludeScope );
+        } else if (isNotEmpty(excludeScope)) {
+            if (!Artifact.SCOPE_COMPILE.equals(excludeScope)
+                    && !Artifact.SCOPE_TEST.equals(excludeScope)
+                    && !Artifact.SCOPE_PROVIDED.equals(excludeScope)
+                    && !Artifact.SCOPE_RUNTIME.equals(excludeScope)
+                    && !Artifact.SCOPE_SYSTEM.equals(excludeScope)) {
+                throw new ArtifactFilterException("Invalid Scope in excludeScope: " + excludeScope);
             }
             results = new LinkedHashSet<>();
             // plexus ScopeArtifactFilter doesn't handle the provided scope so
             // we
             // need special handling for it.
-            if ( Artifact.SCOPE_TEST.equals( excludeScope ) )
-            {
-                throw new ArtifactFilterException( " Can't exclude Test scope, this will exclude everything." );
-            }
-            else if ( !Artifact.SCOPE_PROVIDED.equals( excludeScope ) && !Artifact.SCOPE_SYSTEM.equals( excludeScope ) )
-            {
-                ArtifactFilter saf = new ScopeArtifactFilter( excludeScope );
+            if (Artifact.SCOPE_TEST.equals(excludeScope)) {
+                throw new ArtifactFilterException(" Can't exclude Test scope, this will exclude everything.");
+            } else if (!Artifact.SCOPE_PROVIDED.equals(excludeScope) && !Artifact.SCOPE_SYSTEM.equals(excludeScope)) {
+                ArtifactFilter saf = new ScopeArtifactFilter(excludeScope);
 
-                for ( Artifact artifact : artifacts )
-                {
-                    if ( !saf.include( artifact ) )
-                    {
-                        results.add( artifact );
+                for (Artifact artifact : artifacts) {
+                    if (!saf.include(artifact)) {
+                        results.add(artifact);
                     }
                 }
-            }
-            else
-            {
-                results = excludeSingleScope( artifacts, excludeScope );
+            } else {
+                results = excludeSingleScope(artifacts, excludeScope);
             }
         }
 
         return results;
     }
 
-    private Set<Artifact> includeSingleScope( Set<Artifact> artifacts, String scope )
-    {
+    private Set<Artifact> includeSingleScope(Set<Artifact> artifacts, String scope) {
         Set<Artifact> results = new LinkedHashSet<>();
-        for ( Artifact artifact : artifacts )
-        {
-            if ( scope.equals( artifact.getScope() ) )
-            {
-                results.add( artifact );
+        for (Artifact artifact : artifacts) {
+            if (scope.equals(artifact.getScope())) {
+                results.add(artifact);
             }
         }
         return results;
     }
 
-    private Set<Artifact> excludeSingleScope( Set<Artifact> artifacts, String scope )
-    {
+    private Set<Artifact> excludeSingleScope(Set<Artifact> artifacts, String scope) {
         Set<Artifact> results = new LinkedHashSet<>();
-        for ( Artifact artifact : artifacts )
-        {
-            if ( !scope.equals( artifact.getScope() ) )
-            {
-                results.add( artifact );
+        for (Artifact artifact : artifacts) {
+            if (!scope.equals(artifact.getScope())) {
+                results.add(artifact);
             }
         }
         return results;
@@ -160,8 +135,7 @@ public class ScopeFilter
      *
      * @return Returns the includeScope.
      */
-    public String getIncludeScope()
-    {
+    public String getIncludeScope() {
         return this.includeScope;
     }
 
@@ -171,8 +145,7 @@ public class ScopeFilter
      * @param scope
      *            The includeScope to set.
      */
-    public void setIncludeScope( String scope )
-    {
+    public void setIncludeScope(String scope) {
         this.includeScope = scope;
     }
 
@@ -181,8 +154,7 @@ public class ScopeFilter
      *
      * @return Returns the excludeScope.
      */
-    public String getExcludeScope()
-    {
+    public String getExcludeScope() {
         return this.excludeScope;
     }
 
@@ -192,9 +164,7 @@ public class ScopeFilter
      * @param scope
      *            The excludeScope to set.
      */
-    public void setExcludeScope( String scope )
-    {
+    public void setExcludeScope(String scope) {
         this.excludeScope = scope;
     }
-
 }
