@@ -1,5 +1,3 @@
-package org.apache.maven.shared.artifact.filter.collection;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,15 +7,16 @@ package org.apache.maven.shared.artifact.filter.collection;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
- * under the License.    
+ * under the License.
  */
+package org.apache.maven.shared.artifact.filter.collection;
 
 import org.apache.maven.artifact.Artifact;
 
@@ -26,23 +25,19 @@ import org.apache.maven.artifact.Artifact;
  *
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
  */
-public class TypeFilter
-    extends AbstractArtifactFeatureFilter
-{
+public class TypeFilter extends AbstractArtifactFeatureFilter {
     /**
      * <p>Constructor for TypeFilter.</p>
      *
      * @param include comma separated list with includes.
      * @param exclude comma separated list with excludes.
      */
-    public TypeFilter( String include, String exclude )
-    {
-        super( include, exclude );
+    public TypeFilter(String include, String exclude) {
+        super(include, exclude);
     }
 
     /** {@inheritDoc} */
-    protected String getArtifactFeature( Artifact artifact )
-    {
+    protected String getArtifactFeature(Artifact artifact) {
         return artifact.getType();
     }
 }
