@@ -1,5 +1,3 @@
-package org.apache.maven.shared.artifact.filter.resolve;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.shared.artifact.filter.resolve;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,6 +16,7 @@ package org.apache.maven.shared.artifact.filter.resolve;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.shared.artifact.filter.resolve;
 
 /**
  * Represents a node of a dependency graph
@@ -25,13 +24,11 @@ package org.apache.maven.shared.artifact.filter.resolve;
  * @author Robert Scholte
  * @since 3.0
  */
-public interface Node
-{
+public interface Node {
     /**
      * <p>getDependency.</p>
      *
      * @return {@link org.apache.maven.model.Dependency}
      */
     org.apache.maven.model.Dependency getDependency();
-
 }
