@@ -1,5 +1,3 @@
-package org.apache.maven.shared.artifact.filter.resolve;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.shared.artifact.filter.resolve;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,6 +16,7 @@ package org.apache.maven.shared.artifact.filter.resolve;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.shared.artifact.filter.resolve;
 
 import java.util.Collection;
 import java.util.Collections;
@@ -42,28 +41,25 @@ import java.util.Collections;
  * @see org.eclipse.aether.util.filter.PatternExclusionsDependencyFilter
  * @see org.eclipse.aether.version.VersionScheme
  */
-public class PatternExclusionsFilter implements TransformableFilter
-{
-    
+public class PatternExclusionsFilter implements TransformableFilter {
+
     private final Collection<String> excludes;
-    
+
     /**
      * The default constructor specifying a collection of pattern based keys which must be excluded.
      *
      * @param excludes the excludes, must not be {@code null}
      */
-    public PatternExclusionsFilter( Collection<String> excludes )
-    {
-        this.excludes = Collections.unmodifiableCollection( excludes );
+    public PatternExclusionsFilter(Collection<String> excludes) {
+        this.excludes = Collections.unmodifiableCollection(excludes);
     }
-    
+
     /**
      * Get the excludes
      *
      * @return the excluded keys, never {@code null}
      */
-    public final Collection<String> getExcludes()
-    {
+    public final Collection<String> getExcludes() {
         return excludes;
     }
 
@@ -73,8 +69,7 @@ public class PatternExclusionsFilter implements TransformableFilter
      * Transform this filter to a tool specific implementation
      */
     @Override
-    public <T> T transform( FilterTransformer<T> transformer )
-    {
-        return transformer.transform( this );
+    public <T> T transform(FilterTransformer<T> transformer) {
+        return transformer.transform(this);
     }
 }
