@@ -1,5 +1,3 @@
-package org.apache.maven.shared.artifact.filter.resolve;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.shared.artifact.filter.resolve;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,6 +16,7 @@ package org.apache.maven.shared.artifact.filter.resolve;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.shared.artifact.filter.resolve;
 
 import java.util.Arrays;
 import java.util.Collection;
@@ -30,8 +29,7 @@ import java.util.Collections;
  * @since 3.0
  * @see org.eclipse.aether.util.filter.ScopeDependencyFilter
  */
-public class ScopeFilter implements TransformableFilter
-{
+public class ScopeFilter implements TransformableFilter {
     private final Collection<String> excluded;
 
     private final Collection<String> included;
@@ -42,21 +40,19 @@ public class ScopeFilter implements TransformableFilter
      * @param included specific scopes to include or {@code null} to include all
      * @param excluded specific scopes to exclude or {@code null} to exclude none
      */
-    public ScopeFilter( Collection<String> included, Collection<String> excluded )
-    {
-        this.included = ( included == null ? null : Collections.unmodifiableCollection( included ) );
-        this.excluded = ( excluded == null ? null : Collections.unmodifiableCollection( excluded ) );
+    public ScopeFilter(Collection<String> included, Collection<String> excluded) {
+        this.included = (included == null ? null : Collections.unmodifiableCollection(included));
+        this.excluded = (excluded == null ? null : Collections.unmodifiableCollection(excluded));
     }
-    
+
     /**
      * Construct a ScopeFilter based on included scopes
      *
      * @param included the scopes to include, may be {@code null}
      * @return the filter, never {@code null}
      */
-    public static ScopeFilter including( Collection<String> included ) 
-    {
-        return new ScopeFilter( included, null );
+    public static ScopeFilter including(Collection<String> included) {
+        return new ScopeFilter(included, null);
     }
 
     /**
@@ -65,9 +61,8 @@ public class ScopeFilter implements TransformableFilter
      * @param included the scopes to include, must not be {@code null}
      * @return the filter, never {@code null}
      */
-    public static ScopeFilter including( String... included ) 
-    {
-        return new ScopeFilter( Arrays.asList( included ), null );
+    public static ScopeFilter including(String... included) {
+        return new ScopeFilter(Arrays.asList(included), null);
     }
 
     /**
@@ -76,9 +71,8 @@ public class ScopeFilter implements TransformableFilter
      * @param excluded the scopes to exclude, may be {@code null}
      * @return the filter, never {@code null}
      */
-    public static ScopeFilter excluding( Collection<String> excluded ) 
-    {
-        return new ScopeFilter( null, excluded );
+    public static ScopeFilter excluding(Collection<String> excluded) {
+        return new ScopeFilter(null, excluded);
     }
 
     /**
@@ -87,9 +81,8 @@ public class ScopeFilter implements TransformableFilter
      * @param excluded the scopes to exclude, must not be {@code null}
      * @return the filter, never {@code null}
      */
-    public static ScopeFilter excluding( String... excluded ) 
-    {
-        return new ScopeFilter( null, Arrays.asList( excluded ) );
+    public static ScopeFilter excluding(String... excluded) {
+        return new ScopeFilter(null, Arrays.asList(excluded));
     }
 
     /**
@@ -97,28 +90,25 @@ public class ScopeFilter implements TransformableFilter
      *
      * @return the scopes to exclude, may be {@code null}
      */
-    public final Collection<String> getExcluded()
-    {
+    public final Collection<String> getExcluded() {
         return excluded;
     }
-    
+
     /**
      * Get the included scopes
      *
      * @return the scopes to include, may be {@code null}
      */
-    public final Collection<String> getIncluded()
-    {
+    public final Collection<String> getIncluded() {
         return included;
     }
-    
+
     /**
      * {@inheritDoc}
      *
      * Transform this filter to a tool specific implementation
      */
-    public <T> T transform ( FilterTransformer<T> transformer )
-    {
-        return transformer.transform( this );
+    public <T> T transform(FilterTransformer<T> transformer) {
+        return transformer.transform(this);
     }
 }
